CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_neutrinos.h Source File

CCL

ccl_neutrinos.h
Go to the documentation of this file.
1
3 //#pragma once
4 #include "ccl_core.h"
5 #include "gsl/gsl_spline.h"
6 #include "gsl/gsl_const_mksa.h"
7
8 // maximum number of species
9 #define CCL_MAX_NU_SPECIES 3
10 // limits for the precomputed spline of phase
11 // space diagram in MNU/T
12 #define CCL_NU_MNUT_MIN 1e-4
13 #define CCL_NU_MNUT_MAX 500
14 // and number of points
15 #define CCL_NU_MNUT_N 1000
16
17 // The combination of constants required in Omeganuh2
18 #define NU_CONST (8. * pow(M_PI,5) *pow((KBOLTZ/ HPLANCK),3)* KBOLTZ/(15. *pow( CLIGHT,3))* (8. * M_PI * GNEWT) / (3. * 100.*100.*1000.*1000. /MPC_TO_METER /MPC_TO_METER * CLIGHT * CLIGHT))
19
27 gsl_spline* calculate_nu_phasespace_spline(int *status);
28
41 double Omeganuh2 (double a, double Neff, double mnu, double TCMB, gsl_interp_accel* accel, int * status);
42
calculate_nu_phasespace_spline
gsl_spline * calculate_nu_phasespace_spline(int *status)
Definition: ccl_neutrinos.c:28
ccl_core.h
Omeganuh2
double Omeganuh2(double a, double Neff, double mnu, double TCMB, gsl_interp_accel *accel, int *status)
Definition: ccl_neutrinos.c:94